package totaylor;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.core.config.BridgeConfiguration;
import org.hornetq.core.config.CoreQueueConfiguration;
import org.hornetq.core.config.DivertConfiguration;
import org.hornetq.core.config.impl.ConfigurationImpl;
import org.hornetq.core.remoting.impl.invm.InVMAcceptorFactory;
import org.hornetq.core.remoting.impl.netty.NettyAcceptorFactory;
import org.hornetq.core.remoting.impl.netty.NettyConnectorFactory;
import org.hornetq.core.remoting.impl.netty.TransportConstants;
import org.hornetq.core.server.HornetQServer;
import org.hornetq.core.server.HornetQServers;
import org.hornetq.core.server.JournalType;

public class Node1 {

    static final String ADDRESS = "192.168.1.144";
    static final int PORT = 12345;

    public static void main(String[] args) {
        ConfigurationImpl cfg = new ConfigurationImpl();
        
        // acceptors (local addr: 192.168.1.144:12345)
        Map<String, Object> params = new HashMap<String, Object>();
        params.put(TransportConstants.HOST_PROP_NAME, ADDRESS);
        params.put(TransportConstants.PORT_PROP_NAME, PORT);
        TransportConfiguration nettyTransport = new TransportConfiguration(NettyAcceptorFactory.class.getName(), params, "hello-acceptor");
        cfg.getAcceptorConfigurations().add(nettyTransport);
        cfg.getAcceptorConfigurations().add(new TransportConfiguration(InVMAcceptorFactory.class.getName()));

        // connector (connect to 192.168.1.144:23456)
        String connectorName = String.format("connector[%d]", Node2.PORT);
        Map<String, Object> connectorTranspParams = new HashMap<String, Object>();
        connectorTranspParams.put(TransportConstants.USE_NIO_PROP_NAME, true);
        connectorTranspParams.put(TransportConstants.HOST_PROP_NAME, Node2.ADDRESS);
        connectorTranspParams.put(TransportConstants.PORT_PROP_NAME, Node2.PORT);
        TransportConfiguration connTranspConf = new TransportConfiguration(NettyConnectorFactory.class.getName(), connectorTranspParams, connectorName);
        cfg.getConnectorConfigurations().put(connectorName, connTranspConf);

        // dir settings
        cfg.setJournalDirectory("g:/temp/node1/journal");
        cfg.setLargeMessagesDirectory("g:/temp/node1/lm");
        cfg.setBindingsDirectory("g:/temp/node1/bindings");

        // queues
        CoreQueueConfiguration queue1 = new CoreQueueConfiguration("queue1", "queue1", null, true);
        CoreQueueConfiguration queue2 = new CoreQueueConfiguration("queue2", "queue2", null, true);
        cfg.getQueueConfigurations().add(queue1);
        cfg.getQueueConfigurations().add(queue2);

        // divert(queue1 -> queue2)
        DivertConfiguration dc = new DivertConfiguration("hellodivert", "hellodivert", "queue1", "queue2", true, null, null);
        cfg.getDivertConfigurations().add(dc);

        // bridge(node1:queue2 -> node2:queue1)
        List<String> list = new ArrayList<String>();
        list.add(connectorName);
        BridgeConfiguration bc = new BridgeConfiguration("hello-bridge", "queue2", "queue1", null, null, 1000, 1, -1, true, 1000000, 1000, list, false, "", "");
        cfg.getBridgeConfigurations().add(bc);

        // others
        cfg.setPersistenceEnabled(true);
        cfg.setJournalType(JournalType.NIO);
        cfg.setSecurityEnabled(false);

        HornetQServer hqserver = HornetQServers.newHornetQServer(cfg);
        try {
            hqserver.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
