package totaylor;

import java.io.File;
import java.io.FileOutputStream;
import java.util.HashMap;

import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.api.core.client.ClientConsumer;
import org.hornetq.api.core.client.ClientMessage;
import org.hornetq.api.core.client.ClientSession;
import org.hornetq.api.core.client.ClientSessionFactory;
import org.hornetq.api.core.client.HornetQClient;
import org.hornetq.api.core.client.ServerLocator;
import org.hornetq.core.remoting.impl.netty.NettyConnectorFactory;
import org.hornetq.core.remoting.impl.netty.TransportConstants;

public class Receive {

    public static void main(String[] args) {
        {
            // node1, queue1
            try {
                ClientMessage msg = receive(Node1.ADDRESS, Node1.PORT, "queue1");
                System.out.println(String.format("[%s:%d,queue=%s] expected to be null: %s", Node1.ADDRESS, Node1.PORT, "queue1", msg));
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        {
            // node1, queue2
            try {
                ClientMessage msg = receive(Node1.ADDRESS, Node1.PORT, "queue2");
                System.out.println(String.format("[%s:%d,queue=%s] expected to be null: %s", Node1.ADDRESS, Node1.PORT, "queue2", msg));
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        {
            // node2, queue1
            HashMap<String, Object> params = new HashMap<String, Object>();
            params.put(TransportConstants.HOST_PROP_NAME, Node2.ADDRESS);
            params.put(TransportConstants.PORT_PROP_NAME, Node2.PORT);
            ServerLocator locator = HornetQClient.createServerLocatorWithoutHA(new TransportConfiguration(NettyConnectorFactory.class.getName(), params));
            locator.setAckBatchSize(1);

            FileOutputStream fos = null;
            ClientSessionFactory csf = null;
            try {
                csf = locator.createSessionFactory();
                ClientSession session = csf.createSession();
                ClientConsumer consumer = session.createConsumer("queue1");
                session.start();
                final ClientMessage msg = consumer.receive(1000L);
                if (msg == null) {
                    throw new RuntimeException();
                }
                System.out.println(String.format("[%s:%d,queue=%s] received message", Node1.ADDRESS, Node1.PORT, "queue1"));
                System.out.println(String.format("receive message from %s:%d[queue=%s], messageName=%s",
                                                 Node2.ADDRESS,
                                                 Node2.PORT,
                                                 "queue1",
                                                 msg.getStringProperty("name")));

                fos = new FileOutputStream(new File("g:/temp/ggg.jar"));
                msg.saveToOutputStream(fos);
                msg.acknowledge();
                
            } catch (Exception e) {
                e.printStackTrace();
            } finally {
                if (locator != null) {
                    locator.close();
                }
                if (csf != null) {
                    csf.close();
                }
            }
        }
    }

    private static ClientMessage receive(String addr, int port, String queue) throws Exception {
        HashMap<String, Object> params = new HashMap<String, Object>();
        params.put(TransportConstants.HOST_PROP_NAME, addr);
        params.put(TransportConstants.PORT_PROP_NAME, port);
        ServerLocator locator = HornetQClient.createServerLocatorWithoutHA(new TransportConfiguration(NettyConnectorFactory.class.getName(), params));
        locator.setAckBatchSize(1);

        ClientSessionFactory csf = null;
        try {
            csf = locator.createSessionFactory();
            ClientSession session = csf.createSession();
            ClientConsumer consumer = session.createConsumer(queue);
            session.start();
            return consumer.receive(1000L);
        } finally {
            if (locator != null) {
                locator.close();
            }
            if (csf != null) {
                csf.close();
            }
        }
    }
}
